@@ -12,9 +12,9 @@
       real(8),intent(in):: sig  ! cross seccion in mb on this target
       record /ptcl/ a(*)  !output. generated ptcls
       integer,intent(out):: ntp  ! # of generated ptcls
-c/////////////
-      integer i
-c/////////////
+
+      logical ok
+      integer inela, loop
       record /ptcl/ tg  !  
 
       if(ia == 1 ) then
@@ -27,15 +27,35 @@ c/////////////
       endif
       tg.fm.p(4) = tg.mass
       tg.fm.p(1:3)= 0.
+
+      ok = .false.
       call cjamini(pj, tg, sig)
-      call cjam(a, ntp)
+      do while (.not. ok)
+         call cjam(pj, a, ntp, inela)
+c          jam cannot disable elastic collision.
+c        for non heavy, we can use total x-section
+c        which includes elastic one, but for heavy
+c        we cannot get elastic cross-section. So we have to 
+c          wait until inelastic collsion for heavy.
+c        
+         ok = pj.code /= kgnuc .or.  inela /= 0
+      enddo
+      call cjamElaInfo(0, inela)  ! inform inela
       call crot3mom( pj, a, ntp )   ! rotate to the current  cooord
-c////////////
-c      do i = 1, ntp
-c         write(0, '(3i4,1p,4g12.3)')
-c     *   i, a(i).code,a(i).charge, a(i).fm.p(1:4)
-c      enddo
-c////////
+      end
+      subroutine cjamElaInfo(inout, inela)
+      implicit none
+      integer,intent(in)::   inout ! 0--> inela is input
+                                   ! 1--> //    output
+      integer,intent(inout):: inela  ! 0--> jam interaction is elastic
+                                  !  1--> //                  inelastic
+      integer,save::saveinela  ! keep input inela
+      
+      if(inout == 0) then
+         saveinela = inela
+      else
+         inela = saveinela
+      endif
       end
 
       subroutine cjamini(pj, tg, sig)
@@ -105,7 +125,10 @@ c	targ = '2:1'
       endif
 c      call kseblk(cwin, "*", nc)
 c      cwin = '14.6gevc'
-
+c///////////
+c      write(0,*) ' jaminit bmax=',bmax, ' sig=',sig, ' targ=',targ,
+c     *   'proj=',proj
+c//////////////
       call jaminit(mevent, bmin, bmax, dt, nstep, frame, proj, targ,
      *  cwin)
       end
@@ -171,37 +194,65 @@ c         very rare: regard it as proton
          stop
       endif
       end
-      subroutine cjam(a, ntp)
+      subroutine cjam(pj, a, ntp, inela)
 c      implicit none  ! this cannot be used since jam1.inc uses
 c      implicit double (...)
 #include "jam1.inc"
 #include "jam2.inc"
-
 #include "Zptcl.h"
 
       integer ntp
+      record /ptcl/pj
       record /ptcl/a(*)
-
+      integer,intent(out):: inela ! =0  elastic event
+                                  ! =1  inelastic event
       integer i
       integer code, subcode, charge
       integer iev/1/
       save
+c///////////
+cc            these are to see the collsion of incident
+cc            particles only
+c      record /ptcl/ inci
+c      integer,save::first=0
+c      real*8  tgTE, pjTE
+c      if( first == 0 ) then
+c         inci = pj
+c         first = 1
+c      endif
+c///////////
 
       call jamevt(iev)
       ntp = 0
+      inela = 0
+c////////////
+c      tgTE =0.
+c      pjTE = 0.
+c///////////
       do i = 1, nv
          if( k(1,i) <= 11 .and. k(1,i) >= 0  ) then
-c            write(0,*) i,k(2,i), p(1,i), p(2,i), p(3,i),
-c     *             p(4,i), p(5,i)
+c//////////
+c            if( pj.fm.p(4) > inci.fm.p(4)*0.98) then
+c               call ckf2cos(k(2,i), code, subcode, charge)
+c               write(*,'("***",4i4)') i, code,subcode, charge
+c               write(*,'("k(1:7)=",7i8)') k(1:7,i)
+c               write(*,'("px,y,z,E=",1p,4g12.3)') p(1:4,i)
+c               if( k(7,i) < 0 )  then
+c                  pjTE = pjTE + p(4,i)
+c               else
+c                  tgTE = tgTE + p(4,i) 
+c               endif
+c            endif
 c ///////////////////////// should be modifed in future
 #ifdef NEGTARGETSPEC
 c               Nara san's spec is -1 for target but seems to be
 c               incorrect and 1 must be used
-c            if( k(7,i) == -1 ) cycle ! target spectator is neglected
-c
             if( k(7,i) == 1 ) cycle ! target spectator is neglected
 #endif
-c//////////////////////////
+            if( abs(k(7,i)) > 1 ) then
+               inela = 1
+            endif
+
             call ckf2cos(k(2,i), code, subcode, charge)
             ntp = ntp + 1
             call cmkptc(code, subcode, charge, a(ntp))
@@ -212,7 +263,15 @@ c//////////////////////////
 
 c            write(*,*) i, k(2,i), p(1,i), p(2,i), p(3,i),
 c     *             p(4,i), p(5,i)
-
          endif
       enddo
+c///////////////
+c      if( pj.fm.p(4) > inci.fm.p(4)*0.98 ) then
+c         write(*,*) 'pjTE=',pjTE, ' pj. =',pj.fm.p(4)
+c         write(*,*) 'tgKE=',tgTE, ' Mt=', pjTE+tgTE-pj.fm.p(4)
+c         write(*,*)
+c         write(*,*) "====================="
+c         write(*,*)
+c      endif
+c/////////////////
       end
