@@ -12,8 +12,8 @@
 #include "Zobsp.h"
 #include "Zobsv.h"
 #include  "Zstackv.h"
-#include "Zprivate.f"
-#include "Zprivate2.f"
+#include "Zprivate.h"
+#include "Zprivate2.h"
 #include "../Zabsorb.h"
       integer id  ! input.  1 ==> aTrack is going out from
 c                                 outer boundery.
@@ -34,7 +34,7 @@ c      record /coord/ angle
       integer iij, code
       integer i1, i2, ic
       integer ir,  ifai, l, ridx, faiidx
-      real*8  E0, cosz, limit ! limit is not used; we put first col.depth
+      real*8  E0, cosz
       real*8  fai0, fai, sint
       real*8  delta  
       integer reducedTime
@@ -42,7 +42,7 @@ c      record /coord/ angle
       integer klena
       integer w2hl(MaxNoOfSites)
       real*8 r, Eloss, rinmu, cosang
-      real*8 dedt, rho, dist, disto, BinFai
+      real*8 dedt, dedtF, rho, dist, disto, BinFai
       real*8 aa
       real*8 wx, wy, wz, temp
       real   za
@@ -52,8 +52,8 @@ c      record /coord/ angle
       data BinFai/30./
       integer ldep
 c     integer ndummy
-      character*9 ptcl(4)
-      data ptcl/"Photons", "Electrons","Muons", "hadron"/
+      character*9 ptcln(4)
+      data ptcln/"Photons", "Electrons","Muons", "hadron"/
       character*9 ptcl2(3)
       data ptcl2/"Electrons", "Muons","All"/
       real power(4)
@@ -69,12 +69,15 @@ c     integer ndummy
       logical dosort
       real*4  wt, stime
       real*8 sumEbydEdx, sumEbyDeath,sumEbyDeathNeu,sumEbyDeathNut
+      real*8 sumEbyDeathE, sumEbyDeathG, sumEbyDeathMuPiK, 
+     *      sumEbyDeathP, sumEbyDeathO
       real*8 sumEcrash, sumEspace
       real*8 sumAll, sumdEinAir, sumMissing, sumUncertain
+      integer vn/2/ ! version number for the fnoB output
       save 
 
 c     ***********************
-      include "interface1.f"
+      include "interface1.h"
 c     *********************
 
 
@@ -97,9 +100,11 @@ c            center of the bin:
          rbin(i) = r
          r = r* dr
       enddo
-
+#if defined (MACOSX)
+#else
 c            specify bin or ascii output
       call kwhistso( binw )
+#endif
 
       return      
 c     *********************************** hook for Beginning of  1 event
@@ -158,7 +163,8 @@ c          estimate time minimum and time bin for eeach web sector
      *        ldep, i,  webmin )
       enddo
 
-
+#if defined (MACOSX)
+#else
 c     histogram: instanciate
 c           t spectrum at each web sector
       if(tkrtspec) then
@@ -168,7 +174,7 @@ c                at  center
                call kwhisti( tspec0(j, i),
      *          -5., 0.05, 200, b'00000')
                call kwhistai( tspec0(j, i),
-     *         "Arrival time dist. of "//ptcl(j)//" at center",
+     *         "Arrival time dist. of "//ptcln(j)//" at center",
      *         "t", "ptcls", .false., 0., "time", "ns")
 c                   clear
                call kwhistc(tspec0(j, i))
@@ -191,7 +197,7 @@ c                   clear
      *                    tmin,  dt, 2000,   b'00000')
 
                      call kwhistai( tspec(j, ir, ifai,  i),
-     *                "Arrival time of "//ptcl(j)//" at (r,fai)",
+     *                "Arrival time of "//ptcln(j)//" at (r,fai)",
      *                "rt", "ptcls", .false., 0., "time", "ns")
 c                     clear 
                      call kwhistc(tspec(j, ir, ifai, i))
@@ -210,7 +216,7 @@ c            lateral in each fai bin
                   call kwhisti(rspec(j, ifai, i),
      *                 rmin, bin, nrbin,  b'00011' )
                   call kwhistai(rspec(j, ifai, i), 
-     *            "Lateral Dist. of "//ptcl(j)//" at  diff. azimuth",
+     *            "Lateral Dist. of "//ptcln(j)//" at  diff. azimuth",
      *            "ar", "ptcls", .true.,  power(j),   "r", "m.u")
 c                     clear
                   call  kwhistc( rspec(j, ifai, i) )
@@ -218,7 +224,7 @@ c                     clear
             enddo
          enddo
       endif
-            
+#endif
 
       obstimes = 0.
 
@@ -271,13 +277,9 @@ c     ************
          elseif(code .eq. kelec) then
             Ne(ldep) = Ne(ldep) + aTrack.wgt
          elseif(code .eq. kmuon) then
-            if(Ek .gt. 50.e-3) then
-               Nmu(ldep) = Nmu(ldep) + aTrack.wgt
-            endif
+            Nmu(ldep) = Nmu(ldep) + aTrack.wgt
          elseif(code .le. 6) then
-            if(Ek .gt. 50.e-3) then
-               Nhad(ldep) = Nhad(ldep) +aTrack.wgt
-            endif
+            Nhad(ldep) = Nhad(ldep) +aTrack.wgt
          endif
 c            ---------- compute energy loss 
          if(aTrack.p.charge .ne. 0  ) then
@@ -302,9 +304,11 @@ c                 for safety
                dist =1000.
             endif
 
-            call cqElossRate(dedt) !  loss rate GeV/(kg/m^2)
+            call cqElossRate(dedt,dedtF) !  loss rate GeV/(kg/m^2)
+c                     dedtF is the full eloss ; dedt is the restricted
+c                     loss.  We may better use full here.
 c                       energy in 1 g/cm2 of vertical direction
-            Eloss =min( real(dedt*dist), Ek)   !  GeV/(g/cm2)
+            Eloss =min( real(dedtF*dist), Ek)   !  GeV/(g/cm2)
             Eloss = Eloss*aTrack.wgt !  GeV/(g/cm2)
             SumEloss(ldep)=SumEloss(ldep) + Eloss
          else
@@ -331,6 +335,8 @@ c              fai is  in    -15 to 345  (for dfai=30.)
 c 
 c  do following   for specified histo layers (typically only 1 layer)
 c
+#if defined  (MACOSX)
+#else
             if( w2hl(ldep)  .gt. 0 ) then
                i = w2hl(ldep)
                if(tkarspec) then
@@ -354,6 +360,7 @@ c
                   endif
                endif
             endif
+#endif
          endif
       endif
       return
@@ -375,7 +382,7 @@ c///////////////
       call cqFirstID(firstcdepth)
       firstcdepth = firstcdepth* 0.1     ! in g/cm2  First col depth.
 
-      limit = firstcdepth   !  for .nrfai file
+
 
       if(ObserveAS) then
          cog = 0.
@@ -423,28 +430,39 @@ c              to deep penetration
          filename = basefilename2(1:klena(basefilename2))//".hyb"
          call copenfw2(fnoB, filename, 1, icon)
          write(fnoB,
-     *   '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, 1pE11.3, 0p,  2f7.0)')
+     *   '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, 1pE11.3, 0p,
+     *     2f7.0,i2,a )')
      *      EventNo,  inci.p.code,
      *      inci.p.subcode, inci.p.charge,
      *      inci.p.fm.e, -angle.r(1), -angle.r(2), -angle.r(3),
-     *      firstcdepth, cog, cog2
+     *      firstcdepth, cog, cog2, vn, ' /'
 
          sumEbydEdx = 0.
-         sumEbyDeath = 0.
+         sumEbyDeathG =0.
+         sumEbyDeathE =0.
+         sumEbyDeathMuPiK =0.
          sumEbyDeathNeu = 0.
          sumEbyDeathNut = 0.
+         sumEbyDeathP = 0.
+         sumEbyDeathO = 0.
+         sumEbyDeath = 0.
+         sumUncertain = 0.
          sumEcrash = 0.
          sumEspace = 0.
          do i = 1, NoOfASSites 
             if(Eabsorb(1) .ne. 0) then
                write(fnoB, '("t ", i3, 2f7.1,  2f6.3,
-     *         1p8E11.3 )')
+     *         1p14g12.3 )')
      *           i, 
      *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
      *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
      *          Ng(i), Ne(i), Nmu(i), Nhad(i),
      *          ASObsSites(i).esize, SumEloss(i), 
-     *          dEbydEdx(i), dEbyDeath(i)
+     *          dEbydEdx(i), dEbyDeath(i), 
+c                   next ones are from 7.51
+     *          dEbyDeathG(i),  dEbyDeathE(i), dEbyDeathMuPiK(i), 
+     *          dEbyDeathP(i),  dEbyDeathNut(i), dEbyDeathO(i)
+
                if(i .le. Eabsorb(2) ) then
 c                    to see E consv. we should not count
 c                    level > Eabsorb(2).
@@ -452,6 +470,12 @@ c                    level > Eabsorb(2).
                   sumEbyDeath = sumEbyDeath + dEbyDeath(i)
                   sumEbyDeathNeu = sumEbyDeathNeu +dEbyDeathNeu(i)
                   sumEbyDeathNut = sumEbyDeathNut +dEbyDeathNut(i)
+                  sumEbyDeathG = sumEbyDeathG + dEbyDeathG(i)
+                  sumEbyDeathE = sumEbyDeathE + dEbyDeathE(i)
+                  sumEbyDeathMuPiK = sumEbyDeathMuPiK +
+     *                   dEbyDeathMuPiK(i)
+                  sumEbyDeathP = sumEbyDeathP +dEbyDeathP(i)
+                  sumEbyDeathO = sumEbyDeathO +dEbyDeathO(i)
                endif
             else
                write(fnoB, '("t ", i3, 2f7.1,  2f6.3,
@@ -478,7 +502,7 @@ c                    level > Eabsorb(2).
 
             sumMissing =  sumEcrash + sumEspace + sumEbyDeathNeu
             sumUncertain = sumEbyDeathNut
-            sumdEinAir =  sumEbydEdx+sumEbyDeath
+            sumdEinAir =  sumEbydEdx + sumEbyDeath
             sumAll = sumdEinAir + sumMissing + sumUncertain
 
             write(fnoB,'("s ", 1p8E11.3)') 
@@ -487,11 +511,15 @@ c                    level > Eabsorb(2).
      *       sumEbyDeathNeu, sumAll
 
             write(fnoB,'("r ", 1p4E11.3)') 
-     *      sumdEinAir/E0, sumUncertain/E0,sumMissing/E0, sumAll/E0
+     *      sumdEinAir/E0, sumUncertain/E0, sumMissing/E0, sumAll/E0
 c                normalized one
             write(fnoB,'("n ", 1p4E11.3)') 
      *      sumdEinAir/sumAll, sumUncertain/sumAll,sumMissing/sumAll,
      *      1.0
+c                additional info for more details
+            write(fnoB,'("a ", 1p5g12.3 )')
+     *      sumEbyDeathG,  sumEbyDeathE,  sumEbyDeathMuPiK,
+     *      sumEbyDeathP,  sumEbyDeathO
          endif
       endif
       write(fnoB,*)
@@ -506,7 +534,8 @@ c                normalized one
      *   ASObsSites(j).age, ASDepthList(j)*0.1/cog2,
      *   ASObsSites(j).mu, int(cog2)
       enddo
-
+#if defined  (MACOSX)
+#else
       if(tkarspec) then
          filename = basefilename2(1:klena(basefilename2))//"-r.hist"
          call copenfw2(fnoL, filename, binw, icon)
@@ -514,7 +543,7 @@ c                normalized one
             k=histdep(i)
             do j = 1, 4
                write(dirstr,'(a,"/d",i4, "/")')
-     *              ptcl(j), int( DepthList(k)*0.1 )
+     *              ptcln(j), int( DepthList(k)*0.1 )
                call kseblk(dirstr, "|", nstr)
                do l = 1, nfai
                   call kwhistdir(rspec(j, l,  i),  dirstr)
@@ -544,7 +573,7 @@ c                        *********** deallocate ********
                k=histdep(i)
                dirstr = " "
                write( dirstr,'(a,"/d",i4, "/")')
-     *              ptcl(j), int( ASDepthList(k)*0.1 )
+     *              ptcln(j), int( ASDepthList(k)*0.1 )
                call kseblk( dirstr, "|", nstr)
                call kwhistdir( tspec0(j,i),  dirstr )
                call kwhistp( tspec0(j,i),  fnoT )
@@ -562,7 +591,7 @@ c                 *********** deallocate ********
                      call kwhistid( tspec(j,ir, ifai,i), evid(i))
                      dirstr = " "
                      write(dirstr,'(a,"/d",i4, "/F",i2,"/")')
-     *                    ptcl(j), int( DepthList(k)*0.1), ifai
+     *                    ptcln(j), int( DepthList(k)*0.1), ifai
                      call kseblk(dirstr, "|", nstr)
                      call kwhistdir(tspec(j,ir, ifai,i),  dirstr)
                      call kwhistp( tspec(j,ir, ifai,i),  fnoT)
@@ -574,15 +603,15 @@ c                        *********** deallocate ********
          enddo   ! depth loop    
          close(fnoT)
       endif
-
+#endif
 c          output web data
       if(tkweb) then
          filename = basefilename2(1:klena(basefilename2))//".nrfai"
          call copenfw2(fnoN, filename, 1, icon)
          
          write(fnoN,
-     *   '(i4,1pE11.3, 0p,i3, f8.4, 1pE11.3,0p, 4i4, 1pE11.3)')
-     *   EventNo, E0, NN, cosz, limit, nrbin, nfai, ansites,
+     *   '(i4,1pE11.3, 0p,i3, f8.4, 1pE11.3,0p, 4i4, 1p,8g11.3)')
+     *   EventNo, E0, NN, cosz, firstcdepth, nrbin, nfai, ansites,
      *   NoOfSites, KEminObs   ! this is not exist in the older version          
 c                                                                      
 c           dE/dx lateral                                              
